@@ -9,7 +9,7 @@ from sql.functions import NthValue
 
 from trytond.i18n import gettext
 from trytond.model import (
-    ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check)
+    ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check, SymbolMixin)
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.rpc import RPC
@@ -18,7 +18,7 @@ from trytond.pyson import Eval
 from .exceptions import RateError
 
 
-class Currency(DeactivableMixin, ModelSQL, ModelView):
+class Currency(SymbolMixin, DeactivableMixin, ModelSQL, ModelView):
     'Currency'
     __name__ = 'currency.currency'
     name = fields.Char('Name', required=True, translate=True,
@@ -145,8 +145,6 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
 
     @classmethod
     def _round(cls, amount, factor, rounding):
-        if not factor:
-            return amount
         with localcontext() as ctx:
             ctx.prec = max(ctx.prec, (amount / factor).adjusted() + 1)
             # Divide and multiple by factor for case factor is not 10En
@@ -156,9 +154,7 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
 
     def is_zero(self, amount):
         'Return True if the amount can be considered as zero for the currency'
-        if not self.rounding:
-            return not amount
-        return abs(self.round(amount)) < abs(self.rounding)
+        return abs(self.round(amount)) < self.rounding
 
     @classmethod
     def compute(cls, from_currency, amount, to_currency, round=True):
@@ -228,6 +224,16 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
                 ))
         return query
 
+    def get_symbol(self, sign, symbol=None):
+        pool = Pool()
+        Lang = pool.get('ir.lang')
+        lang = Lang.get()
+        symbol, position = super().get_symbol(sign, symbol=symbol)
+        if ((sign < 0 and lang.n_cs_precedes)
+                or (sign >= 0 and lang.p_cs_precedes)):
+            position = 0
+        return symbol, position
+
 
 class CurrencyRate(ModelSQL, ModelView):
     "Currency Rate"
